@@ -10,11 +10,11 @@ Dancer2::Debugger - Dancer2 panels for Plack::Debugger
 
 =head1 VERSION
 
-0.007
+0.008
 
 =cut
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use Dancer2::Core::Types;
 use File::Spec;
@@ -25,6 +25,7 @@ use Plack::App::Debugger;
 use Plack::Builder ();
 use Plack::Debugger;
 use Plack::Debugger::Storage;
+use Plack::Middleware::Debugger::Injector;
 
 use Moo;
 use namespace::clean;
@@ -176,6 +177,23 @@ has filename_fmt => (
     default => '%s.json',
 );
 
+=head2 injector_ignore_status
+
+If set to a true value then we override
+L<Plack::Middleware::Debugger::Injector/should_ignore_status> to always
+return false so that the injector tries to add the javascript snippet to the
+page irrespective of the http status code.
+
+Defaults to false.
+
+=cut
+
+has injector_ignore_status => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
 =head2 panels
 
 Array reference of panel class names to load. Defaults to all classes
@@ -255,6 +273,22 @@ has storage => (
 
 =head1 METHODS
 
+=head2 BUILD
+
+Handle L</injector_ignore_status> if it is true.
+
+=cut
+
+sub BUILD {
+    my $self = shift;
+    if ( $self->injector_ignore_status ) {
+        no warnings 'redefine';
+        *Plack::Middleware::Debugger::Injector::should_ignore_status = sub {
+            return 0;
+        };
+    }
+}
+
 =head2 enable
 
 Convenience method for use in psgi file which runs the following methods:
